# Changelog

## [1.4.2] - 2020-04-10

### Added
+ 5.25 weather data

## [1.4.1] - 2019-06-29

### Added
+ 5.1 weather data

## [1.4.0] - 2019-06-29

### Added
+ 5.0 weather data

### Deleted
+ `EorzeaWeather.forecast_weather()`

## [1.3.0] - 2019-06-25

### Added
+ forecast in EorzeaWeather

### Changed
+ rewrite docstring

### Deprecated
+ forecast_weather in EorzeaWeather is deprecated

